California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Go to Section:
| Statewide Candidates
| State Senate Candidates
| State Assembly Candidates
Choose an Election: 2022 PRIMARY 2021 SPECIAL ELECTION (ASSEMBLY 54) Prior Elections 2021 SPECIAL ELECTION (ASSEMBLY 79) 2021 SPECIAL ELECTION (STATE SENATE 30) 2020 GENERAL 2020 SPECIAL RUNOFF (STATE SENATE 28) 2020 PRIMARY 2020 SPECIAL ELECTION (STATE SENATE 28) 2019 SPECIAL RUNOFF (ASSEMBLY 01) 2019 SPECIAL ELECTION (ASSEMBLY 01) 2019 SPECIAL RUNOFF (STATE SENATE 01) 2019 SPECIAL RUNOFF (STATE SENATE 33) 2019 SPECIAL ELECTION (STATE SENATE 01) 2019 SPECIAL ELECTION (STATE SENATE 33) 2018 GENERAL 2018 SPECIAL RUNOFF (STATE SENATE 32) 2018 PRIMARY 2018 SPECIAL ELECTION (STATE SENATE 32) 2018 SPECIAL ELECTION (STATE SENATE 29) 2018 SPECIAL RUNOFF (ASSEMBLY 45) 2018 SPECIAL RUNOFF (ASSEMBLY 39) 2018 SPECIAL ELECTION (ASSEMBLY 45) 2018 SPECIAL ELECTION (ASSEMBLY 54) 2018 SPECIAL ELECTION (ASSEMBLY 39) 2017 SPECIAL RUNOFF (ASSEMBLY 51) 2017 SPECIAL ELECTION (ASSEMBLY 51) 2016 GENERAL 2016 PRIMARY 2016 SPECIAL ELECTION (ASSEMBLY 31) 2015 SPECIAL RUNOFF (STATE SENATE 07) 2015 SPECIAL ELECTION (STATE SENATE 37) 2015 SPECIAL ELECTION (STATE SENATE 21) 2015 SPECIAL ELECTION (STATE SENATE 07) 2014 SPECIAL ELECTION (STATE SENATE 35) 2014 GENERAL 2014 PRIMARY 2014 SPECIAL ELECTION (STATE SENATE 23) 2013 SPECIAL ELECTION (ASSEMBLY 54) 2013 SPECIAL RUNOFF (ASSEMBLY 45) 2013 SPECIAL RUNOFF (ASSEMBLY 52) 2013 SPECIAL ELECTION (STATE SENATE 26) 2013 SPECIAL ELECTION (ASSEMBLY 45) 2013 SPECIAL ELECTION (ASSEMBLY 52) 2013 SPECIAL RUNOFF (STATE SENATE 16) 2013 SPECIAL ELECTION (ASSEMBLY 80) 2013 SPECIAL ELECTION (STATE SENATE 16) 2013 SPECIAL RUNOFF (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 40) 2013 SPECIAL ELECTION (STATE SENATE 32) 2013 SPECIAL ELECTION (STATE SENATE 04) 2012 GENERAL 2012 SPECIAL ELECTION (STATE SENATE 04) 2012 PRIMARY 2011 SPECIAL RUNOFF (ASSEMBLY 04) 2011 SPECIAL ELECTION (ASSEMBLY 04) 2011 SPECIAL ELECTION (STATE SENATE 17) 2011 SPECIAL ELECTION (STATE SENATE 28) 2011 SPECIAL RUNOFF (STATE SENATE 01) 2010 GENERAL 2010 SPECIAL ELECTION (STATE SENATE 01) 2010 SPECIAL RUNOFF (STATE SENATE 15) 2010 SPECIAL ELECTION (STATE SENATE 15) 2010 PRIMARY 2010 SPECIAL RUNOFF (STATE SENATE 37) 2010 SPECIAL RUNOFF (ASSEMBLY 43) 2010 SPECIAL ELECTION (STATE SENATE 37) 2010 SPECIAL ELECTION (ASSEMBLY 43) 2010 SPECIAL RUNOFF (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 72) 2009 SPECIAL ELECTION (ASSEMBLY 51) 2009 SPECIAL RUNOFF (STATE SENATE 26) 2009 SPECIAL ELECTION (STATE SENATE 26) 2008 GENERAL 2008 PRIMARY 2008 RECALL (STATE SENATE 12) 2008 SPECIAL RUNOFF (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 55) 2007 SPECIAL ELECTION (ASSEMBLY 39) 2006 GENERAL 2006 PRIMARY 2006 SPECIAL RUNOFF (STATE SENATE 35) 2006 SPECIAL ELECTION (STATE SENATE 35) 2005 SPECIAL ELECTION (ASSEMBLY 53) 2004 GENERAL 2004 PRIMARY 2003 SPECIAL ELECTION (GOVERNOR) 2002 GENERAL 2002 PRIMARY 2001 SPECIAL ELECTION (ASSEMBLY 49) 2001 SPECIAL RUNOFF (ASSEMBLY 65) 2001 SPECIAL ELECTION (STATE SENATE 24) 2001 SPECIAL ELECTION (ASSEMBLY 65) 2000 GENERAL 2000 PRIMARY
Also check Late Contribution filings. These reports are independent of the comprehensive disclosure reports that are linked here until semi-annual filings are submitted.
STATEWIDE OFFICES
GOVERNOR
BROWN, EDMUND G. (JERRY) KASHKARI, NEEL
| LIEUTENANT GOVERNOR
NEHRING, RON NEWSOM, GAVIN
SECRETARY OF STATE
PADILLA, ALEX PETERSON, PETE N.
| CONTROLLER
SWEARENGIN, ASHLEY YEE, BETTY T.
TREASURER
CHIANG, JOHN CONLON, GREG
| ATTORNEY GENERAL
GOLD, RONALD HARRIS, KAMALA D.
SUPERINTENDENT OF PUBLIC INSTRUCTION
TORLAKSON, TOM TUCK, MARSHALL
| INSURANCE COMMISSIONER
GAINES, EDWARD T JONES, DAVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
PARKER, CHRIS R. RUNNER, GEORGE C.
| MEMBER BOARD OF EQUALIZATION 02
MA, FIONA THEIS, JAMES E.
MEMBER BOARD OF EQUALIZATION 03
HORTON, JEROME E. MARSHALL, G. RICK
| MEMBER BOARD OF EQUALIZATION 04
HARKEY, DIANE SHAHATIT, NADER F
SENATE DISTRICTS
STATE SENATE 02
MC GUIRE, MIKE WIESNER, LAWRENCE R.
| STATE SENATE 04
JAWAHAR, C J NIELSEN, JIM
STATE SENATE 06
DICKINSON, ROGER PAN, RICHARD
| STATE SENATE 08
BERRYHILL, TOM MIRANDA, PAULINA M.
STATE SENATE 10
KUO, PETER WIECKOWSKI, ROBERT
| STATE SENATE 12
BAGLEY, SHAWN CANNELLA, ANTHONY JOSEPH
STATE SENATE 14
CHAVEZ, LUIS VIDAK, JAMES ANDREW
| STATE SENATE 16
FULLER, JEAN MUSSER-LOPEZ, RUTH
STATE SENATE 18
BENITEZ, RICARDO HERTZBERG, ROBERT
| STATE SENATE 20
LEYVA, CONNIE M. MUNSON, MATTHEW G.
STATE SENATE 22
HERNANDEZ, EDWARD P. RODRIGUEZ, MARC
| STATE SENATE 24
CHOI, PETER DE LEON, KEVIN
STATE SENATE 26
ALLEN, BEN FLUKE, SANDRA
| STATE SENATE 28
GARCIA, BONNIE STONE, JEFFREY E.
STATE SENATE 30
ARMENTA, ISIDRO MITCHELL, HOLLY J.
| STATE SENATE 32
GUERRA, MARIO A. MENDOZA, TONY
STATE SENATE 34
NGUYEN, JANET SOLORIO, JOSE
| STATE SENATE 36
BATES, PATRICIA 'PAT' KEPHART, GARY R.
STATE SENATE 38
ANDERSON, JOEL C. TSIMBOUKAKIS, FOTIOS/FRANK
| STATE SENATE 40
ESTRADA, RAFAEL HUESO, BEN
ASSEMBLY DISTRICTS
ASSEMBLY 01
DAHLE, BRIAN SMITH, BRIGHAM SAWYER
| ASSEMBLY 02
HEATH, MATTHEW D. WOOD, JIM
ASSEMBLY 03
GALLAGHER, JAMES REED, JIM
| ASSEMBLY 04
DODD, BILL SCHAUPP, CHARLES E.
ASSEMBLY 05
BIGELOW, FRANK HOGAN, PATRICK D.
| ASSEMBLY 06
CAPLES, BRIAN GAINES, BETH B.
ASSEMBLY 07
COHN, STEVE MC CARTY, KEVIN
| ASSEMBLY 08
COOLEY, KEN HAALAND, DOUGLAS
ASSEMBLY 09
COOPER, JIM FONG, DARRELL
| ASSEMBLY 10
ALLEN, GREGORY J. LEVINE, MARC
ASSEMBLY 11
FRAZIER, JR., JAMES L HENTHORN, ALEX
| ASSEMBLY 12
GREWAL, HARINDER OLSEN, KRISTIN M.
ASSEMBLY 13
EGGMAN, SUSAN JOBRACK, SOL
| ASSEMBLY 14
BONILLA, SUSAN DELEPINE, JOY D.
ASSEMBLY 15
ECHOLS, ELIZABETH THURMOND, TONY
| ASSEMBLY 16
BAKER, CATHARINE SBRANTI, TIM
ASSEMBLY 17
CAMPOS, DAVID CHIU, DAVID
| ASSEMBLY 18
BONTA, ROB ERLICH, DAVID M.
ASSEMBLY 19
PINEDA, RENE GONZALO TING, PHIL
| ASSEMBLY 20
PATINO, JAIME R. QUIRK, BILL
ASSEMBLY 21
GRAY, ADAM C. MOBLEY JR., JACK M.
| ASSEMBLY 22
GILHAM, MARK MULLIN, KEVIN C.
ASSEMBLY 23
PATTERSON, JIM
| ASSEMBLY 24
GABL, DIANE CHRISTINE GORDON, RICHARD S.
ASSEMBLY 25
BRUNTON, ROBERT L. CHU, KANSEN
| ASSEMBLY 26
MATHIS, DEVON J. MENDOZA, RUDY
ASSEMBLY 27
CAMPOS, NORA ELIA LANCASTER, GORDON K.
| ASSEMBLY 28
LOW, EVAN PAGE, CHUCK
ASSEMBLY 29
KAIN, PALMER STONE, MARK
| ASSEMBLY 30
ALEJO, LUIS STARRITT, MARK
ASSEMBLY 31
PEREA, HENRY T. VILLARREAL, WALTER
| ASSEMBLY 32
RIOS, PEDRO AYON SALAS JR., RUDY
ASSEMBLY 33
COFFEY, JOHN OBERNOLTE, JAY
| ASSEMBLY 34
GOODMAN, VIRGINIA "MARI" GROVE, SHANNON
ASSEMBLY 35
ACHADJIAN, KHATCHIK HARMON, HEIDI
| ASSEMBLY 36
FOX, STEVE LACKEY, THOMAS W.
ASSEMBLY 37
DEBLAUW, RONALD E WILLIAMS, DAS
| ASSEMBLY 38
FUENTES, JORGE SALOMON WILK, SCOTT T.
ASSEMBLY 39
BOCANEGRA, RAUL LOPEZ, PATTY
| ASSEMBLY 40
HENRY, KATHLEEN STEINORTH, MARC
ASSEMBLY 41
HOLDEN, CHRIS
| ASSEMBLY 42
HARGROVE, KARALEE B. MAYES, CHAD
ASSEMBLY 43
GATTO, MIKE ROYAL, TODD
| ASSEMBLY 44
IRWIN, JACQUI V. MC COY, ROB
ASSEMBLY 45
DABABNEH, MATTHEW SHELLEY, SUSAN
| ASSEMBLY 46
NAZARIAN, ADRIN TAYLOR, ZACHARY
ASSEMBLY 47
BROWN, CHERYL NAVARRO, GIL
| ASSEMBLY 48
HERNANDEZ, ROGER LARA-GARDNER, JOSEPH
ASSEMBLY 49
CHAU, ED SIEGRIST, ESTHELA T.
| ASSEMBLY 50
BLOOM, RICHARD TORGAN, BRADLY S.
ASSEMBLY 51
GOMEZ, JIMMY SMITH, STEPHEN C.
| ASSEMBLY 52
PINEDA, DOROTHY RODRIGUEZ, FREDDIE
ASSEMBLY 53
MENDOZA, SANDRA Y. SANTIAGO, MIGUEL
| ASSEMBLY 54
RATCLIFF, GLEN RIDLEY-THOMAS, SEBASTIAN M.
ASSEMBLY 55
CHANG, LING LING FRITCHLE, GREGG D.
| ASSEMBLY 56
BENNETT JR, CHARLES H. GARCIA, EDUARDO
ASSEMBLY 57
CALDERON, IAN TOPALIAN, RITA H.
| ASSEMBLY 58
GARCIA, CRISTINA
ASSEMBLY 59
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 60
LINDER, ERIC PARK, KEN
ASSEMBLY 61
ARANDA, RUDY MEDINA, JOSE J.
| ASSEMBLY 62
BURKE, AUTUMN GROSE, TED
ASSEMBLY 63
MILLER, ADAM J. RENDON, ANTHONY
| ASSEMBLY 64
GIPSON, MIKE WALKER, PROPHET L.
ASSEMBLY 65
KIM, YOUNG O. QUIRK-SILVA, SHARON
| ASSEMBLY 66
HADLEY, DAVID F. MURATSUCHI, AL
ASSEMBLY 67
MELENDEZ, MELISSA MELTON, CONRAD L
| ASSEMBLY 68
CAMERON, ANNE WAGNER, DON
ASSEMBLY 69
DALY, TOM WALKER, SHERRY
| ASSEMBLY 70
GOYA, JOHN C. O'DONNELL, PATRICK
ASSEMBLY 71
JONES, BRIAN W. TEORA, ANTHONY
| ASSEMBLY 72
ALLEN, TRAVIS BLOCK, JOEL
ASSEMBLY 73
BROUGH, WILLIAM (BILL) GABRIELLA, WENDY B.
| ASSEMBLY 74
CURRY, KEITH HARPER, MATTHEW
ASSEMBLY 75
SHESTOPLE, NICHOLAS WALDRON, MARIE
| ASSEMBLY 76
CHAVEZ, ROCKY KROUSE, THOMAS
ASSEMBLY 77
HERNANDEZ, RUBEN MAIENSCHEIN, BRIAN
| ASSEMBLY 78
ATKINS, TONI G. DECKER, BARBARA V.
ASSEMBLY 79
WEBER, SHIRLEY WILLIAMS, GEORGE R.
| ASSEMBLY 80
GONZALEZ, LORENA S.